#!/bin/sh
#

swagger-codegen generate -i ./smartcat.json -l perl -c ./smartcat.config -o ../ --git-user-id ta2-1  --git-repo-id smartcat-api-perl  --release-note "Create Smartcat Intergration API Perl library generated by swagger-codegen"
