
=begin comment

Smartcat Integration API

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: v1

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 2;    #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('Smartcat::Client::CallbackApi');

my $api = Smartcat::Client::CallbackApi->new();
isa_ok( $api, 'Smartcat::Client::CallbackApi' );

#
# callback_delete test
#
#{
#    my $result = $api->callback_delete();
#}

#
# callback_get test
#
#{
#    my $result = $api->callback_get();
#}

#
# callback_get_last_errors test
#
#{
#    my $limit = undef;    # replace NULL with a proper value
#    my $result = $api->callback_get_last_errors( limit => $limit );
#}

#
# callback_update test
#
#{
#    my $callback_property = undef;    # replace NULL with a proper value
#    my $result =
#      $api->callback_update( callback_property => $callback_property );
#}

1;
