
=begin comment

Smartcat Integration API

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: v1

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 2;    #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('Smartcat::Client::PlaceholderFormatApiApi');

my $api = Smartcat::Client::PlaceholderFormatApiApi->new();
isa_ok( $api, 'Smartcat::Client::PlaceholderFormatApiApi' );

#
# placeholder_format_api_get_placeholder_formats test
#
#{
#    my $result = $api->placeholder_format_api_get_placeholder_formats();
#}

#
# placeholder_format_api_update_placeholder_formats test
#
#{
#    my $formats = undef;    # replace NULL with a proper value
#    my $result = $api->placeholder_format_api_update_placeholder_formats(
#        formats => $formats );
#}

#
# placeholder_format_api_validate_placeholder_format test
#
#{
#    my $format = undef;    # replace NULL with a proper value
#    my $result = $api->placeholder_format_api_validate_placeholder_format(
#        format => $format );
#}

1;
