=head1 NAME

Smartcat::Client - Smartcat Integration API client library

=head1 DESCRIPTION

This module is generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen. 
It is used and tested for Smartcat::App only.

=head1 SEE ALSO

Lhttps://github.com/smartcatai/smartcat-api-perl/

=cut

package Smartcat::Client;

our $VERSION = '0.0.3';

1;
