
=begin comment

Smartcat Integration API

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

OpenAPI spec version: v1

Generated by: https://github.com/swagger-api/swagger-codegen.git

=end comment

=cut

#
# NOTE: This class is auto generated by Swagger Codegen
# Please update the test cases below to test the API endpoints.
# Ref: https://github.com/swagger-api/swagger-codegen
#
use Test::More tests => 2;    #TODO update number of test cases
use Test::Exception;

use lib 'lib';
use strict;
use warnings;

use_ok('Smartcat::Client::TranslationMemoriesApi');

my $api = Smartcat::Client::TranslationMemoriesApi->new();
isa_ok( $api, 'Smartcat::Client::TranslationMemoriesApi' );

#
# translation_memories_create_empty_tm test
#
#{
#    my $model = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_create_empty_tm( model => $model );
#}

#
# translation_memories_export_file test
#
#{
#    my $tm_id       = undef;    # replace NULL with a proper value
#    my $export_mode = undef;    # replace NULL with a proper value
#    my $with_tags   = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_export_file(
#        tm_id       => $tm_id,
#        export_mode => $export_mode,
#        with_tags   => $with_tags
#    );
#}

#
# translation_memories_get_meta_info test
#
#{
#    my $tm_id = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_get_meta_info( tm_id => $tm_id );
#}

#
# translation_memories_get_pending_tasks test
#
#{
#    my $result = $api->translation_memories_get_pending_tasks();
#}

#
# translation_memories_get_tm_translations test
#
#{
#    my $request = undef;    # replace NULL with a proper value
#    my $tm_id   = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_get_tm_translations(
#        request => $request,
#        tm_id   => $tm_id
#    );
#}

#
# translation_memories_get_translation_memories_batch test
#
#{
#    my $last_processed_id = undef;    # replace NULL with a proper value
#    my $batch_size        = undef;    # replace NULL with a proper value
#    my $source_language   = undef;    # replace NULL with a proper value
#    my $target_language   = undef;    # replace NULL with a proper value
#    my $client_id         = undef;    # replace NULL with a proper value
#    my $search_name       = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_get_translation_memories_batch(
#        last_processed_id => $last_processed_id,
#        batch_size        => $batch_size,
#        source_language   => $source_language,
#        target_language   => $target_language,
#        client_id         => $client_id,
#        search_name       => $search_name
#    );
#}

#
# translation_memories_import test
#
#{
#    my $tm_id               = undef;    # replace NULL with a proper value
#    my $replace_all_content = undef;    # replace NULL with a proper value
#    my $tmx_file            = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_import(
#        tm_id               => $tm_id,
#        replace_all_content => $replace_all_content,
#        tmx_file            => $tmx_file
#    );
#}

#
# translation_memories_remove_specific_import_task test
#
#{
#    my $task_id = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_remove_specific_import_task(
#        task_id => $task_id );
#}

#
# translation_memories_remove_translation_memory test
#
#{
#    my $tm_id = undef;    # replace NULL with a proper value
#    my $result =
#      $api->translation_memories_remove_translation_memory( tm_id => $tm_id );
#}

#
# translation_memories_set_tm_target_languages test
#
#{
#    my $tm_id            = undef;    # replace NULL with a proper value
#    my $target_languages = undef;    # replace NULL with a proper value
#    my $result = $api->translation_memories_set_tm_target_languages(
#        tm_id            => $tm_id,
#        target_languages => $target_languages
#    );
#}

1;
